@@ -31,9 +31,7 @@ Here is a minimal deployable pattern definition:
 ```javascript
 const { CloudFrontToS3 } = require('@aws-solutions-constructs/aws-cloudfront-s3');
 
-new CloudFrontToS3(stack, 'test-cloudfront-s3', {
-    deployBucket: true
-});
+new CloudFrontToS3(stack, 'test-cloudfront-s3', {});
 
 ```
 
@@ -53,9 +51,8 @@ new CloudFrontToS3(scope: Construct, id: string, props: CloudFrontToS3Props);
 
 | **Name**     | **Type**        | **Description** |
 |:-------------|:----------------|-----------------|
-|deployBucket|`boolean`|Whether to create a S3 Bucket or use an existing S3 Bucket|
-|existingBucketObj?|[`s3.Bucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.Bucket.html)|Existing instance of S3 Bucket object|
-|bucketProps?|[`s3.BucketProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.BucketProps.html)|Optional user provided props to override the default props for S3 Bucket|
+|existingBucketObj?|[`s3.Bucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.Bucket.html)|Existing instance of S3 Bucket object, if this is set then the bucketProps is ignored.|
+|bucketProps?|[`s3.BucketProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.BucketProps.html)|User provided props to override the default props for the S3 Bucket.|
 |cloudFrontDistributionProps?|[`cloudfront.CloudFrontWebDistributionProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-cloudfront.CloudFrontWebDistributionProps.html)|Optional user provided props to override the default props for CloudFront Distribution|
 |insertHttpSecurityHeaders?|`boolean`|Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from CloudFront|
 
@@ -121,17 +118,15 @@ class CloudFrontToS3(
         *,
         bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
         cloud_front_distribution_props: typing.Any = None,
-        deploy_bucket: typing.Optional[bool] = None,
         existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.Bucket] = None,
         insert_http_security_headers: typing.Optional[bool] = None,
     ) -> None:
         """
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
-        :param bucket_props: Optional user provided props to override the default props. If ``deploy`` is set to true only then this property is required Default: - Default props are used
+        :param bucket_props: User provided props to override the default props for the S3 Bucket. Default: - Default props are used
         :param cloud_front_distribution_props: Optional user provided props to override the default props. Default: - Default props are used
-        :param deploy_bucket: Whether to create a S3 Bucket or use an existing S3 Bucket. If set to false, you must provide S3 Bucket as ``existingBucketObj`` Default: - true
-        :param existing_bucket_obj: Existing instance of S3 Bucket object. If ``deployBucket`` is set to false only then this property is required Default: - None
+        :param existing_bucket_obj: Existing instance of S3 Bucket object, if this is set then the bucketProps is ignored. Default: - None
         :param insert_http_security_headers: Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront. Default: - true
 
         access:
@@ -144,7 +139,6 @@ class CloudFrontToS3(
         props = CloudFrontToS3Props(
             bucket_props=bucket_props,
             cloud_front_distribution_props=cloud_front_distribution_props,
-            deploy_bucket=deploy_bucket,
             existing_bucket_obj=existing_bucket_obj,
             insert_http_security_headers=insert_http_security_headers,
         )
@@ -170,7 +164,6 @@ class CloudFrontToS3(
     name_mapping={
         "bucket_props": "bucketProps",
         "cloud_front_distribution_props": "cloudFrontDistributionProps",
-        "deploy_bucket": "deployBucket",
         "existing_bucket_obj": "existingBucketObj",
         "insert_http_security_headers": "insertHttpSecurityHeaders",
     },
@@ -181,15 +174,13 @@ class CloudFrontToS3Props:
         *,
         bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
         cloud_front_distribution_props: typing.Any = None,
-        deploy_bucket: typing.Optional[bool] = None,
         existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.Bucket] = None,
         insert_http_security_headers: typing.Optional[bool] = None,
     ) -> None:
         """
-        :param bucket_props: Optional user provided props to override the default props. If ``deploy`` is set to true only then this property is required Default: - Default props are used
+        :param bucket_props: User provided props to override the default props for the S3 Bucket. Default: - Default props are used
         :param cloud_front_distribution_props: Optional user provided props to override the default props. Default: - Default props are used
-        :param deploy_bucket: Whether to create a S3 Bucket or use an existing S3 Bucket. If set to false, you must provide S3 Bucket as ``existingBucketObj`` Default: - true
-        :param existing_bucket_obj: Existing instance of S3 Bucket object. If ``deployBucket`` is set to false only then this property is required Default: - None
+        :param existing_bucket_obj: Existing instance of S3 Bucket object, if this is set then the bucketProps is ignored. Default: - None
         :param insert_http_security_headers: Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront. Default: - true
 
         summary:
@@ -204,8 +195,6 @@ class CloudFrontToS3Props:
             self._values[
                 "cloud_front_distribution_props"
             ] = cloud_front_distribution_props
-        if deploy_bucket is not None:
-            self._values["deploy_bucket"] = deploy_bucket
         if existing_bucket_obj is not None:
             self._values["existing_bucket_obj"] = existing_bucket_obj
         if insert_http_security_headers is not None:
@@ -213,9 +202,7 @@ class CloudFrontToS3Props:
 
     @builtins.property
     def bucket_props(self) -> typing.Optional[aws_cdk.aws_s3.BucketProps]:
-        """Optional user provided props to override the default props.
-
-        If ``deploy`` is set to true only then this property is required
+        """User provided props to override the default props for the S3 Bucket.
 
         default
         :default: - Default props are used
@@ -231,22 +218,9 @@ class CloudFrontToS3Props:
         """
         return self._values.get("cloud_front_distribution_props")
 
-    @builtins.property
-    def deploy_bucket(self) -> typing.Optional[bool]:
-        """Whether to create a S3 Bucket or use an existing S3 Bucket.
-
-        If set to false, you must provide S3 Bucket as ``existingBucketObj``
-
-        default
-        :default: - true
-        """
-        return self._values.get("deploy_bucket")
-
     @builtins.property
     def existing_bucket_obj(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
-        """Existing instance of S3 Bucket object.
-
-        If ``deployBucket`` is set to false only then this property is required
+        """Existing instance of S3 Bucket object, if this is set then the bucketProps is ignored.
 
         default
         :default: - None
